==> 0.0.1.tar.gz: lib/database_device.dart <==
library database_device;

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

class DatabaseDevice {
  static write(String string) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.setString('data', string);
  }

  static Future<String> read() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    final myString = prefs.getString('data') ?? '';
    return myString;
  }

  static add(Map map) async {
    String reading = await read();
    if (reading.isEmpty || reading.length == 0) {
      String toS = jsonEncode(map);
      write('''{"data":{"data":[$toS],"key":0}}''');
    } else {
      Map maps = jsonDecode(reading);
      maps['data']['key'] += 1;
      maps['data']['data'].add(map);
      Map edite = maps;
      String toS = jsonEncode(edite);
      write(toS);
    }
  }

  static Future<List> get getdataList async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map map = jsonDecode(reading);
      List tol = map['data']['data'];

      return tol;
    } else {
      return [];
    }
  }

  static removeRow(int i) async {
    String reading = await read();
    Map map = jsonDecode(reading);
    if (reading.isNotEmpty && i < map['data']['data'].length) {
      map['data']['data'].removeAt(i);
      String toS = jsonEncode(map);
      write(toS);
    }
  }

  static Future<int> get key async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map map = jsonDecode(reading);
      int i = map['data']['key'];

      return i;
    } else
      return 999999999999999999;
  }

  static removeListRow(List<int> indexes) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map map = jsonDecode(reading);
      for (var i = 0; i < indexes.length; i++) {
        map['data']['data'].removeAt(indexes[i]);
      }
      String toS = jsonEncode(map);
      write(toS);
    }
  }

  static copyAddPast(int i) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map maps = jsonDecode(reading);
      maps['data']['data'].add(maps['data']['data'][i]);
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static moveIteam(int oldIndex, int newIndex) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map<String, dynamic> maps = jsonDecode(reading);
      if (newIndex > oldIndex) {
        newIndex = newIndex - 1;
      }
      final element = maps['data']['data'].removeAt(oldIndex);
      maps['data']['data'].insert(newIndex, element);
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static editeRow(int i, Map map) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map maps = jsonDecode(reading);
      maps['data']['data'][i] = map;
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static editeFildOrFildes(int i, Map<String, dynamic> map) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map<String, dynamic> maps = jsonDecode(reading);
      maps['data']['data'][i].addAll(map);
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static removeAllData() async {
    write('');
  }

  static Widget childFutureBuilder({
    Widget? child,
    required Function(List data, int key) getData,
  }) {
    Future<List> _futureList() async {
      int i = await DatabaseDevice.key;
      List list2 = await DatabaseDevice.getdataList;
      getData(list2, i);

      return list2;
    }

    return FutureBuilder<List>(
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.none &&
            !snapshot.hasData) {
          return Center(
            child: Text(' no data found '),
          );
        }
        return child ?? Center();
      },
      future: _futureList(),
    );
  }
}

==> 0.0.4.tar.gz: lib/database_device.dart <==
library database_device;

import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

class DatabaseDevice {
  static write(String string) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.setString('data', string);
  }

  static Future<String> read() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    final myString = prefs.getString('data') ?? '';
    return myString;
  }

  static Future<int> get lengthChar async {
    String string = await read();
    int lengthe = string.length;
    return lengthe;
  }

  static add(Map map) async {
    String reading = await read();
    if (reading.isEmpty || reading.length == 0) {
      map['key'] = 0;
      String toS = jsonEncode(map);
      write('''{"data":{"data":[$toS],"key":0}}''');
    } else {
      Map maps = jsonDecode(reading);
      maps['data']['key'] += 1;
      map['key'] = maps['data']['key'];
      maps['data']['data'].add(map);
      Map edite = maps;
      String toS = jsonEncode(edite);
      write(toS);
    }
  }

  static Future<List> get getdataList async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map map = jsonDecode(reading);
      List tol = map['data']['data'];

      return tol;
    } else {
      return [];
    }
  }

  static removeRow(int i) async {
    String reading = await read();
    Map map = jsonDecode(reading);
    if (reading.isNotEmpty && i < map['data']['data'].length) {
      map['data']['data'].removeAt(i);
      String toS = jsonEncode(map);
      write(toS);
    }
  }

  static Future<int> get key async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map map = jsonDecode(reading);
      int i = map['data']['key'];

      return i;
    } else
      return 999999999999999999;
  }

  static copyAddPast(int i) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map maps = jsonDecode(reading);
      final map = maps['data']['data'][i];
      add(map);
    }
  }

  static moveIteam(int oldIndex, int newIndex) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map<String, dynamic> maps = jsonDecode(reading);
      if (newIndex > oldIndex) {
        newIndex = newIndex - 1;
      }
      final element = maps['data']['data'].removeAt(oldIndex);
      maps['data']['data'].insert(newIndex, element);
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static editeRow(int i, Map map) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map maps = jsonDecode(reading);
      int key = maps['data']['data'][i]['key'];
      map['key'] = key;
      maps['data']['data'][i] = map;
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static editeFild(int i, Map<String, dynamic> map) async {
    String reading = await read();
    if (reading.isNotEmpty) {
      Map maps = jsonDecode(reading);
      int key = maps['data']['data'][i]['key'];
      map['key'] = key;
      maps['data']['data'][i]..addAll(map);
      String toS = jsonEncode(maps);
      write(toS);
    }
  }

  static removeAllData() async {
    write('');
  }

  static Widget childFutureBuilder({
    Widget? child,
    required Function(List data) getData,
  }) {
    Future<List> _futureList() async {
      List list2 = await DatabaseDevice.getdataList;
      getData(list2);
      return list2;
    }

    return FutureBuilder<List>(
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.none &&
            !snapshot.hasData) {
          return Center(
            child: Text(' no data found '),
          );
        }
        return child ?? Center();
      },
      future: _futureList(),
    );
  }
}
